@@ -9,6 +9,12 @@ root_project = __import__(settings.ROOT_URLCONF)
 try:
   urlpatterns = root_project.urls.urlpatterns
 except AttributeError:
-  urlpatterns = root_project.urlpatterns
+  try:
+    urlpatterns = root_project.urlpatterns
+  except AttributeError:
+    urlpatterns = None
 
-urlpatterns += (url(r'^periscope/', include('periscope.urls')),)
+try:
+  urlpatterns += (url(r'^periscope/', include('periscope.urls')),)
+except TypeError:
+  pass
