@@ -1,14 +1,17 @@
 import json
 import re
-from collections import OrderedDict
+try:
+  from collections import OrderedDict
+except ImportError:
+  from OrderedDict import OrderedDict
 from django.conf import settings
 from django.db import connection, transaction
 from django.http import HttpResponse
 from django.views.decorators.csrf import csrf_exempt
 
-BAD_WORDS = {'drop', 'delete', 'update', 'into', 'insert', 'index', 'add', 'remove', 'grant', 'revoke', 'create',
+BAD_WORDS = set(['drop', 'delete', 'update', 'into', 'insert', 'index', 'add', 'remove', 'grant', 'revoke', 'create',
              'createdb', 'createuser', 'createrole', 'destroy', 'disconnect', 'exec', 'execute', 'dropdb', 'primary',
-             'key', 'rollback', ';', '--'}
+             'key', 'rollback', ';', '--'])
 
 def login_required(view):
   def decorator(request):
